//JAXP packages
import javax.xml.parsers.*;
import org.xml.sax.*;

import java.io.*;
import javax.naming.*;

public class SAXDirReader {
	
/** Champ contenant le fichier a lire */
private String fileName;
private SAXDirReaderProcess saxDirReaderProcess;
	
private static String convertToFileURL(String filename) {
	String path = new File(filename).getAbsolutePath();
	if (File.separatorChar != '/') { path = path.replace(File.separatorChar, '/');}
	if (!path.startsWith("/")) { path = "/" + path;}
	return "file:" + path;
}

public SAXDirReader (String fileName) throws IOException {
	setFileName(fileName);
	boolean dtdValidate = false;
	String schemaSource = null;
        
	// Create a JAXP SAXParserFactory and configure it
	SAXParserFactory spf = SAXParserFactory.newInstance();
	// Set namespaceAware to true to get a parser that corresponds to
	// the default SAX2 namespace feature setting.  This is necessary
	// because the default value from JAXP 1.0 was defined to be false.
	spf.setNamespaceAware(true);
	// Validation part 1: set whether validation is on
	spf.setValidating(dtdValidate);
	try {
		// Create a JAXP SAXParser
		SAXParser saxParser = spf.newSAXParser();
		// Get the encapsulated SAX XMLReader
		XMLReader xmlReader = saxParser.getXMLReader();
		// Set the ContentHandler of the XMLReader
		saxDirReaderProcess = new SAXDirReaderProcess();
		xmlReader.setContentHandler(saxDirReaderProcess);
		// Set an ErrorHandler before parsing
		xmlReader.setErrorHandler(new MyErrorHandler(System.err));
		// Tell the XMLReader to parse the XML document
		xmlReader.parse(convertToFileURL(fileName));
	}
	catch (SAXException saxe) {System.out.println("SAXParser : " + saxe);}
	catch (ParserConfigurationException pce) {System.out.println("SAXParser : " + pce);}
}
    
public String getFileName() {return fileName;}
public void setFileName(String fileName) {this.fileName = fileName;}

public NamingEnumeration getNamingEnumeration() {return saxDirReaderProcess.getNamingEnumeration();}

	
// Error handler to report errors and warnings
private static class MyErrorHandler implements ErrorHandler {
	/** Error handler output goes here */
	private PrintStream out;

	MyErrorHandler(PrintStream out) {this.out = System.out;}

	/**
	 * Returns a string describing parse exception details
	 */
	private String getParseExceptionInfo(SAXParseException spe) {
		String systemId = spe.getSystemId();
		if (systemId == null) {systemId = "null";}
		String info = "URI=" + systemId +
			" Line=" + spe.getLineNumber() +
			": " + spe.getMessage();
		return info;
	}

	// The following methods are standard SAX ErrorHandler methods.
	// See SAX documentation for more info.
	public void warning(SAXParseException spe) throws SAXException {
		out.println("Warning: " + getParseExceptionInfo(spe));
	}
        
	public void error(SAXParseException spe) throws SAXException {
		String message = "Error: " + getParseExceptionInfo(spe);
		throw new SAXException(message);
	}

	public void fatalError(SAXParseException spe) throws SAXException {
		String message = "Fatal Error: " + getParseExceptionInfo(spe);
		throw new SAXException(message);
	}
}
}
